@@ -1,5 +1,6 @@
 
 from seti_python.class_read import ResponseReadCash, ResponseReadCashOut, ResponseReadPayment, ResponseReadTransactions, ResponseReadWallet, ResponseReadWalletsTransactions
+from seti_python.class_users import ResponseCreateUser, ResponseValidateUsersExist
 from seti_python.wallet_class import ResponseCreateWallet
 from seti_python.class_tools import BasicResponse, CompleteBasicaResponse, ResponseCreateDispersions, ResponseCreateTransaction
 from seti_python.payment_class import ResponseCreatePayment
@@ -267,3 +268,22 @@ class Seti():
         READ_TRANSACTIONS_URL = "read-transactions"
         encode_data = self.sign_data(data_read_cash)
         return ResponseReadTransactions(self.send_request(data_read_cash, encode_data, READ_TRANSACTIONS_URL))
+
+    def create_user(self, email: str, first_name: str, phone: str, iso_code: str):
+        self.is_error = False
+        self.validate_email(email)
+        data_read_cash = {"email": email,
+                          "first_name": first_name,
+                          "phone": phone,
+                          "iso_code": iso_code}
+        CREATE_USER_URL = "create-user"
+        encode_data = self.sign_data(data_read_cash)
+        return ResponseCreateUser(self.send_request(data_read_cash, encode_data, CREATE_USER_URL))
+
+    def validate_exist_user(self, email: str):
+        self.is_error = False
+        self.validate_email(email)
+        data_read_cash = {"email": email}
+        CREATE_USER_URL = "validate-user"
+        encode_data = self.sign_data(data_read_cash)
+        return ResponseValidateUsersExist(self.send_request(data_read_cash, encode_data, CREATE_USER_URL))
